@@ -1,10 +1,9 @@
 # $Id: ptte.stat.R,v 1.2 2005/09/26 02:29:00 andrewr Exp $
 
 "ptte.stat" <-
-function(mean, std, n, alpha=0.05, Epsilon=0.25, absolute=FALSE) {
+function(mean, std, n, alpha=0.05, Epsilon=0.25) {
     df1 <- 1; df2 <- n-1; cutoff <- c(0)
     if(length(Epsilon)>1) stop("Asymmetric intervals are not yet implemented")
-    if (absolute) Epsilon <- Epsilon / std
     ncp <- Epsilon^2 * n; 
     findquant <- function(alpha, q, df1, df2, ncp)
         alpha - pf(q, df1, df2, ncp)
